define

package
v0.1.33 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidUserSubj = errors.New("invalid user subj")
	ErrInvalidToHash   = errors.New("ToHash return 0, must implement ToHash and not return 0")
)

Functions

func ProtoMarshalAppend added in v0.1.5

func ProtoMarshalAppend(b []byte, msg proto.Message) ([]byte, error)

func ProtoMessageName added in v0.1.5

func ProtoMessageName(msg proto.Message) protoreflect.FullName

func ProtoSize added in v0.1.5

func ProtoSize(msg proto.Message) int

func ProtoUnmarshal added in v0.1.5

func ProtoUnmarshal(b []byte, msg proto.Message) error

Types

type Clear

type Clear interface {
	Reset()
}

Clear is an interface that can be implemented by a struct to reset its value Just for the convenience of objectpool

type DoNotCopy

type DoNotCopy [0]sync.Mutex

DoNotCopy is an empty structure that can be embedded into a struct to prevent It cannot be copied

type MarshalAppender added in v0.1.5

type MarshalAppender interface {
	MarshalTo(data []byte) (n int, err error)
}

type ProtoMessagePtr

type ProtoMessagePtr[T any] interface {
	proto.Message
	*T
}

ProtoMessagePtr is an interface that can be implemented by a struct to be a proto message pointer for enforce constraints on proto message pointer when using generics

type TraceID added in v0.1.2

type TraceID = xid.IDString

TraceID is an alias of xid.ID

type XXXMessageNamer added in v0.1.5

type XXXMessageNamer interface {
	XXX_MessageName() string
}

Jump to