Documentation
¶
Index ¶
- Variables
- func ProtoMarshalAppend(b []byte, msg proto.Message) ([]byte, error)
- func ProtoMessageName(msg proto.Message) protoreflect.FullName
- func ProtoSize(msg proto.Message) int
- func ProtoUnmarshal(b []byte, msg proto.Message) error
- type Clear
- type DoNotCopy
- type MarshalAppender
- type ProtoMessagePtr
- type TraceID
- type XXXMessageNamer
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidUserSubj = errors.New("invalid user subj") ErrInvalidToHash = errors.New("ToHash return 0, must implement ToHash and not return 0") )
Functions ¶
func ProtoMarshalAppend ¶ added in v0.1.5
func ProtoMessageName ¶ added in v0.1.5
func ProtoMessageName(msg proto.Message) protoreflect.FullName
Types ¶
type Clear ¶
type Clear interface {
Reset()
}
Clear is an interface that can be implemented by a struct to reset its value Just for the convenience of objectpool
type DoNotCopy ¶
DoNotCopy is an empty structure that can be embedded into a struct to prevent It cannot be copied
type MarshalAppender ¶ added in v0.1.5
type ProtoMessagePtr ¶
ProtoMessagePtr is an interface that can be implemented by a struct to be a proto message pointer for enforce constraints on proto message pointer when using generics
type XXXMessageNamer ¶ added in v0.1.5
type XXXMessageNamer interface {
XXX_MessageName() string
}
Click to show internal directories.
Click to hide internal directories.